def get_user_input(prompt="Enter input: "):
    """
    Get text input from the user.
    
    Args:
        prompt (str): The message to display to the user
    
    Returns:
        The user's input as a string
    """
    user_input = input(prompt)
    return user_input